function res = motionCorrection(data,pkx,pky,dread,dpe,peorder)
% MOTIONCORRECTION correct for 2D motion in a 2D image
%    MOTIONCORRECTION(DATA,PKX,PKY,DX,DY,YORDER)
%    corrects for the motion specified in vectors DX, and DY. 
%    The vectors PKX and PKY describe values of k-space:
%
%       kr = ((1:nro)-1)*PKX(2)+PKX(1); % Readout direction
%       kp = ((1:npe)-1)*PKY(2)+PKY(1); % Phase-encode direction
%
%    Motion vectors DX and DY all have the same length and are
%    ordered by time. YORDER describes the ordering of the phase
%    -encodes. Note that X is the readout direction and Y is the 
%    phase-encode direction.
%
% See also MOTIONAUTOFOCUS and MOTIONCORRECTION3.
%
% (c) Joseph Y Cheng (jycheng@mrsrl.stanford.edu) 2012
    
% SVN info: 
%   Date:     $Date: 2012-02-14 16:18:31 -0800 (Tue, 14 Feb 2012) $
%   Revision: $Revision: 192 $
%   Author:   $Author: jycheng $
%   Id:       $Id: motionCorrection.m 192 2012-02-15 00:18:31Z jycheng $
       
    DEBUG = 0;
    
    if DEBUG
        tic;
    end
    res = data;
        
    nro = size(data,1);
    npe = size(data,2);

    kro = ((1:nro)-1)*pkx(2)+pkx(1);
    kpe = ((1:npe)-1)*pky(2)+pky(1);
    
    %% Tranverse through time (using peorder)
    for M=1:length(peorder)
        res(:,peorder(M)) = data(:,peorder(M))...
            .*exp(1i*2*pi*(kro(:)*dread(M)+kpe(M)*dpe(M)));
    end
    
    if DEBUG
        t = toc;        
        dbdisp(sprintf('Done correction: %0.4f s',t));
    end